@@ -3,39 +3,40 @@
  *
  *  Copyright (c) 2007-2008 Brian Tarricone <bjt23@cornell.edu>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License ONLY.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; version 2
+ *  of the License ONLY.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __XFCONF_CHANNEL_H__
 #define __XFCONF_CHANNEL_H__
 
-#if !defined(LIBXFCONF_COMPILATION) && !defined(XFCONF_IN_XFCONF_H)
+#if !defined(LIBXFCONF_COMPILATION) && !defined(__XFCONF_IN_XFCONF_H__)
 #error "Do not include xfconf-channel.h, as this file may change or disappear in the future.  Include <xfconf/xfconf.h> instead."
 #endif
 
 #include <glib-object.h>
 
-#define XFCONF_TYPE_CHANNEL             (xfconf_channel_get_type())
-#define XFCONF_CHANNEL(obj)             (G_TYPE_CHECK_INSTANCE_CAST((obj), XFCONF_TYPE_CHANNEL, XfconfChannel))
-#define XFCONF_IS_CHANNEL(obj)          (G_TYPE_CHECK_INSTANCE_TYPE((obj), XFCONF_TYPE_CHANNEL))
-#define XFCONF_CHANNEL_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST((klass), XFCONF_TYPE_CHANNEL, XfconfChannelClass))
-#define XFCONF_IS_CHANNEL_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE((klass), XFCONF_TYPE_CHANNEL))
-#define XFCONF_CHANNEL_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), XFCONF_TYPE_CHANNEL, XfconfChannelClass))
+#define XFCONF_TYPE_CHANNEL (xfconf_channel_get_type())
+#define XFCONF_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), XFCONF_TYPE_CHANNEL, XfconfChannel))
+#define XFCONF_IS_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), XFCONF_TYPE_CHANNEL))
+#define XFCONF_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), XFCONF_TYPE_CHANNEL, XfconfChannelClass))
+#define XFCONF_IS_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), XFCONF_TYPE_CHANNEL))
+#define XFCONF_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), XFCONF_TYPE_CHANNEL, XfconfChannelClass))
 
 G_BEGIN_DECLS
 
-typedef struct _XfconfChannel         XfconfChannel;
+typedef struct _XfconfChannel XfconfChannel;
 
 GType xfconf_channel_get_type(void) G_GNUC_CONST;
 
@@ -109,7 +110,7 @@ gchar **xfconf_channel_get_string_list(XfconfChannel *channel,
                                        const gchar *property) G_GNUC_WARN_UNUSED_RESULT;
 gboolean xfconf_channel_set_string_list(XfconfChannel *channel,
                                         const gchar *property,
-                                        const gchar * const *values);
+                                        const gchar *const *values);
 
 /* really generic API - can set some value types that aren't
  * supported by the basic type API, e.g., char, signed short,
@@ -191,7 +192,7 @@ gboolean xfconf_channel_set_structv(XfconfChannel *channel,
                                     guint n_members,
                                     GType *member_types);
 
-#if 0  /* future (maybe) */
+#if 0 /* future (maybe) */
 
 //gboolean xfconf_channel_begin_transaction(XfconfChannel *channel);
 //gboolean xfconf_channel_commit_transaction(XfconfChannel *channel);
@@ -201,4 +202,4 @@ gboolean xfconf_channel_set_structv(XfconfChannel *channel,
 
 G_END_DECLS
 
-#endif  /* __XFCONF_CHANNEL_H__ */
+#endif /* __XFCONF_CHANNEL_H__ */
